Adding --enable-checking=release to gcc
-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1
I added the above option to gcc and did core-image-sato build to see if I would gain some compile time performance.
The results were not very astounding but I do see some improvement
original
real 102m50.131s user 437m7.463s sys 67m29.237s
with --enable-checking=release
real 102m19.762s user 439m41.749s sys 66m10.376s
This was using shared state for native packages but cross packages were all built too. overall gain in pecents will be more since we would then
subtract the time it took to compile the cross tools.
This patch is for gcc-4.7 recipes as of now.
Thanks
- -Khem
-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.4.11 (GNU/Linux)
Comment: Using GnuPG with Mozilla - http://enigmail.mozdev.org/
iEYEARECAAYFAk9/42cACgkQuwUzVZGdMxS41wCfZb8YPP12HeWY35FGZINTc/+z Ar0AniVM2osnwuPJFpgO2P/QrurW6HHl
=HzWp
-----END PGP SIGNATURE-----